@@ -1,16 +1,13 @@
 "bags" <- function(data = NULL, kat = NULL, conf.level = 0.95) {
   
   cl <- match.call()
-  data <- data.matrix(data)
+  data <- as.matrix(na.omit(data))
   nr <- nrow(data)
   nc <- ncol(data)
+  data <- matrix(as.numeric(as.factor(data)),nr,nc)
   
   if (nc!=2){
     stop("The data frame needs to be formatted as a n*2 matrix!")
-  } else if (!is.numeric(data)){
-    stop("A numeric data matrix is required")
-  } else if (min(data,na.rm=TRUE)<1){
-    data <- data+abs(1-min(data,na.rm=TRUE))
   } 
   
   if (is.numeric(kat)){
@@ -32,12 +29,14 @@
   
   res <- structure(list(method = "Bennett et al.'s S",
                         call = cl,
+                        obs = nc,
                         sample = nr,
                         est = S,
-                        std.err = se,
+                        se = se,
                         conf.level = conf.level,
-                        ci.lower = lb,
-                        ci.upper = ub),
-                      class="rel")
+                        lb = lb,
+                        ub = ub,
+                        data = data),
+                      class = "rel")
   return(res)
 }
\ No newline at end of file
